<?php
/**
 * Copyright 2003-2006 Marko Djukic <marko@oblo.com>
 * Copyright 2003-2006 Chuck Hagenbuch <chuck@horde.org>
 *
 * $Horde: jonah/channels/edit.php,v 1.27 2006/01/07 19:50:45 chuck Exp $
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://cvs.horde.org/co.php/jonah/LICENSE.
 */

@define('JONAH_BASE', dirname(__FILE__) . '/..');
require_once JONAH_BASE . '/lib/base.php';
require_once JONAH_BASE . '/lib/News.php';
require_once JONAH_BASE . '/lib/Forms/Feed.php';
require_once 'Horde/Form.php';
require_once 'Horde/Form/Renderer.php';
require_once 'Horde/Variables.php';

$news = &Jonah_News::singleton();
$renderer = &new Horde_Form_Renderer();

/* Set up the form variables and the form. */
$vars = &Variables::getDefaultVariables();
$formedit = &Horde_Form::singleton('FeedForm', $vars);

/* Set up some variables. */
$formname = $vars->get('formname');
$channel_id = $vars->get('channel_id');

/* Form not yet submitted and is being edited. */
if (!$formname && $channel_id) {
    $vars = &new Variables($news->getChannel($channel_id));
}

/* Get the vars for channel type. */
$channel_type = $vars->get('channel_type');
$old_channel_type = $vars->get('old_channel_type');
$changed_type = false;

/* Check permissions and deny if not allowed. */
if (!Jonah::checkPermissions(Jonah::typeToPermName($channel_type), PERMS_EDIT, $channel_id)) {
    $notification->push(_("You are not authorised for this action."), 'horde.warning');
    Horde::authenticationFailureRedirect();
}

/* If this is null then new form, so set both to default. */
if (is_null($channel_type)) {
    $channel_type = Jonah_News::getDefaultType();
    $old_channel_type = $channel_type;
}

/* Check if channel type has been changed and notify. */
if ($channel_type != $old_channel_type && $formname) {
    $changed_type = true;
    $notification->push(_("Feed type changed."), 'horde.message');
}
$vars->set('old_channel_type', $channel_type);

/* Output the extra fields required for this channel type. */
$formedit->setExtraFields($channel_type, $channel_id);

if ($formname && !$changed_type) {
    if ($formedit->validate($vars)) {
        $formedit->getInfo($vars, $info);
        $save = $news->saveChannel($info);
        if (is_a($save, 'PEAR_Error')) {
            $notification->push(sprintf(_("There was an error saving the feed: %s"), $save->getMessage()), 'horde.error');
        } else {
            $notification->push(sprintf(_("The feed \"%s\" has been saved."), $info['channel_name']), 'horde.success');
            if ($channel_type == JONAH_AGGREGATED_CHANNEL) {
                $notification->push(_("You can now edit the sub-feeds."), 'horde.message');
            } else {
                header('Location: ' . Horde::applicationUrl('channels/index.php', true));
                exit;
            }
        }
    }
}

$main = Util::bufferOutput(array($formedit, 'renderActive'), $renderer, $vars, 'edit.php', 'post');

$template = &new Horde_Template();
$template->set('main', $main);
$template->set('menu', Jonah::getMenu('string'));
$template->set('notify', Util::bufferOutput(array($notification, 'notify'), array('listeners' => 'status')));

$title = $formedit->getTitle();
require JONAH_TEMPLATES . '/common-header.inc';
echo $template->fetch(JONAH_TEMPLATES . '/main/main.html');
require $registry->get('templates', 'horde') . '/common-footer.inc';
